@@ -145,13 +145,15 @@ def is_attrdict(val: Any) -> bool:
 not_attrdict = complement(is_attrdict)
 
 
-TRANSACTION_FORMATTERS = {
+TRANSACTION_RESULT_FORMATTERS = {
     'blockHash': apply_formatter_if(is_not_null, to_hexbytes(32)),
     'blockNumber': apply_formatter_if(is_not_null, to_integer_if_hex),
     'transactionIndex': apply_formatter_if(is_not_null, to_integer_if_hex),
     'nonce': to_integer_if_hex,
     'gas': to_integer_if_hex,
     'gasPrice': to_integer_if_hex,
+    'maxFeePerGas': to_integer_if_hex,
+    'maxPriorityFeePerGas': to_integer_if_hex,
     'value': to_integer_if_hex,
     'from': to_checksum_address,
     'publicKey': apply_formatter_if(is_not_null, to_hexbytes(64)),
@@ -165,7 +167,7 @@ TRANSACTION_FORMATTERS = {
 }
 
 
-transaction_formatter = apply_formatters_to_dict(TRANSACTION_FORMATTERS)
+transaction_result_formatter = apply_formatters_to_dict(TRANSACTION_RESULT_FORMATTERS)
 
 
 def apply_list_to_array_formatter(formatter: Any) -> Callable[..., Any]:
@@ -200,12 +202,14 @@ RECEIPT_FORMATTERS = {
     'logsBloom': to_hexbytes(256),
     'from': apply_formatter_if(is_not_null, to_checksum_address),
     'to': apply_formatter_if(is_address, to_checksum_address),
+    'effectiveGasPrice': to_integer_if_hex,
 }
 
 
 receipt_formatter = apply_formatters_to_dict(RECEIPT_FORMATTERS)
 
 BLOCK_FORMATTERS = {
+    'baseFeePerGas': to_integer_if_hex,
     'extraData': to_hexbytes(32, variable_length=True),
     'gasLimit': to_integer_if_hex,
     'gasUsed': to_integer_if_hex,
@@ -225,7 +229,7 @@ BLOCK_FORMATTERS = {
     'stateRoot': to_hexbytes(32),
     'totalDifficulty': to_integer_if_hex,
     'transactions': apply_one_of_formatters((
-        (is_array_of_dicts, apply_list_to_array_formatter(transaction_formatter)),
+        (is_array_of_dicts, apply_list_to_array_formatter(transaction_result_formatter)),
         (is_array_of_strings, apply_list_to_array_formatter(to_hexbytes(32))),
     )),
     'transactionsRoot': to_hexbytes(32),
@@ -250,11 +254,11 @@ syncing_formatter = apply_formatters_to_dict(SYNCING_FORMATTERS)
 TRANSACTION_POOL_CONTENT_FORMATTERS = {
     'pending': compose(
         curried.keymap(to_ascii_if_bytes),
-        curried.valmap(transaction_formatter),
+        curried.valmap(transaction_result_formatter),
     ),
     'queued': compose(
         curried.keymap(to_ascii_if_bytes),
-        curried.valmap(transaction_formatter),
+        curried.valmap(transaction_result_formatter),
     ),
 }
 
@@ -274,6 +278,16 @@ transaction_pool_inspect_formatter = apply_formatters_to_dict(
     TRANSACTION_POOL_INSPECT_FORMATTERS
 )
 
+FEE_HISTORY_FORMATTERS = {
+    'baseFeePerGas': apply_formatter_to_array(to_integer_if_hex),
+    'gasUsedRatio': apply_formatter_if(is_not_null, apply_formatter_to_array(float)),
+    'oldestBlock': to_integer_if_hex,
+    'reward': apply_formatter_if(is_not_null, apply_formatter_to_array(
+        apply_formatter_to_array(to_integer_if_hex))),
+}
+
+fee_history_formatter = apply_formatters_to_dict(FEE_HISTORY_FORMATTERS)
+
 STORAGE_PROOF_FORMATTERS = {
     'key': HexBytes,
     'value': HexBytes,
@@ -308,9 +322,16 @@ filter_result_formatter = apply_one_of_formatters((
     (is_array_of_strings, apply_list_to_array_formatter(to_hexbytes(32))),
 ))
 
+TRANSACTION_REQUEST_FORMATTERS = {
+    'maxFeePerGas': to_hex_if_integer,
+    'maxPriorityFeePerGas': to_hex_if_integer,
+}
 
+transaction_request_formatter = apply_formatters_to_dict(TRANSACTION_REQUEST_FORMATTERS)
 transaction_param_formatter = compose(
     remove_key_if('to', lambda txn: txn['to'] in {'', b'', None}),
+    remove_key_if('gasPrice', lambda txn: txn['gasPrice'] in {'', b'', None}),
+    transaction_request_formatter,
 )
 
 
@@ -346,7 +367,7 @@ estimate_gas_with_block_id = apply_formatters_to_sequence([
 
 SIGNED_TX_FORMATTER = {
     'raw': HexBytes,
-    'tx': transaction_formatter,
+    'tx': transaction_result_formatter,
 }
 
 signed_tx_formatter = apply_formatters_to_dict(SIGNED_TX_FORMATTER)
@@ -371,6 +392,7 @@ geth_wallets_formatter = apply_formatters_to_dict(GETH_WALLETS_FORMATTER)
 
 PYTHONIC_REQUEST_FORMATTERS: Dict[RPCEndpoint, Callable[..., Any]] = {
     # Eth
+    RPC.eth_feeHistory: apply_formatter_at_index(to_hex_if_integer, 1),
     RPC.eth_getBalance: apply_formatter_at_index(to_hex_if_integer, 1),
     RPC.eth_getBlockByNumber: apply_formatter_at_index(to_hex_if_integer, 0),
     RPC.eth_getBlockTransactionCountByNumber: apply_formatter_at_index(
@@ -401,6 +423,7 @@ PYTHONIC_REQUEST_FORMATTERS: Dict[RPCEndpoint, Callable[..., Any]] = {
         (is_length(2), estimate_gas_with_block_id),
     )),
     RPC.eth_sendTransaction: apply_formatter_at_index(transaction_param_formatter, 0),
+    RPC.eth_signTransaction: apply_formatter_at_index(transaction_param_formatter, 0),
     RPC.eth_getProof: apply_formatter_at_index(to_hex_if_integer, 2),
     # personal
     RPC.personal_importRawKey: apply_formatter_at_index(
@@ -429,6 +452,8 @@ PYTHONIC_RESULT_FORMATTERS: Dict[RPCEndpoint, Callable[..., Any]] = {
     RPC.eth_coinbase: to_checksum_address,
     RPC.eth_call: HexBytes,
     RPC.eth_estimateGas: to_integer_if_hex,
+    RPC.eth_feeHistory: fee_history_formatter,
+    RPC.eth_maxPriorityFeePerGas: to_integer_if_hex,
     RPC.eth_gasPrice: to_integer_if_hex,
     RPC.eth_getBalance: to_integer_if_hex,
     RPC.eth_getBlockByHash: apply_formatter_if(is_not_null, block_formatter),
@@ -440,16 +465,17 @@ PYTHONIC_RESULT_FORMATTERS: Dict[RPCEndpoint, Callable[..., Any]] = {
     RPC.eth_getFilterLogs: filter_result_formatter,
     RPC.eth_getLogs: filter_result_formatter,
     RPC.eth_getProof: apply_formatter_if(is_not_null, proof_formatter),
+    RPC.eth_getRawTransactionByHash: HexBytes,
     RPC.eth_getStorageAt: HexBytes,
     RPC.eth_getTransactionByBlockHashAndIndex: apply_formatter_if(
         is_not_null,
-        transaction_formatter,
+        transaction_result_formatter,
     ),
     RPC.eth_getTransactionByBlockNumberAndIndex: apply_formatter_if(
         is_not_null,
-        transaction_formatter,
+        transaction_result_formatter,
     ),
-    RPC.eth_getTransactionByHash: apply_formatter_if(is_not_null, transaction_formatter),
+    RPC.eth_getTransactionByHash: apply_formatter_if(is_not_null, transaction_result_formatter),
     RPC.eth_getTransactionCount: to_integer_if_hex,
     RPC.eth_getTransactionReceipt: apply_formatter_if(
         is_not_null,
@@ -585,33 +611,53 @@ def get_request_formatters(
 
 
 def raise_block_not_found(params: Tuple[BlockIdentifier, bool]) -> NoReturn:
-    block_identifier = params[0]
-    raise BlockNotFound(f"Block with id: {block_identifier!r} not found.")
+    try:
+        block_identifier = params[0]
+        message = f"Block with id: {block_identifier!r} not found."
+    except IndexError:
+        message = "Unknown block identifier"
+
+    raise BlockNotFound(message)
 
 
 def raise_block_not_found_for_uncle_at_index(
     params: Tuple[BlockIdentifier, Union[HexStr, int]]
 ) -> NoReturn:
-    block_identifier = params[0]
-    uncle_index = to_integer_if_hex(params[1])
-    raise BlockNotFound(
-        f"Uncle at index: {uncle_index} of block with id: "
-        f"{block_identifier!r} not found."
-    )
+    try:
+        block_identifier = params[0]
+        uncle_index = to_integer_if_hex(params[1])
+        message = (
+            f"Uncle at index: {uncle_index} of block with id: "
+            f"{block_identifier!r} not found."
+        )
+    except IndexError:
+        message = "Unknown block identifier or uncle index"
+
+    raise BlockNotFound(message)
 
 
 def raise_transaction_not_found(params: Tuple[_Hash32]) -> NoReturn:
-    transaction_hash = params[0]
-    raise TransactionNotFound(f"Transaction with hash: {transaction_hash!r} not found.")
+    try:
+        transaction_hash = params[0]
+        message = f"Transaction with hash: {transaction_hash!r} not found."
+    except IndexError:
+        message = "Unknown transaction hash"
+
+    raise TransactionNotFound(message)
 
 
 def raise_transaction_not_found_with_index(params: Tuple[BlockIdentifier, int]) -> NoReturn:
-    block_identifier = params[0]
-    transaction_index = to_integer_if_hex(params[1])
-    raise TransactionNotFound(
-        f"Transaction index: {transaction_index} "
-        f"on block id: {block_identifier!r} not found."
-    )
+    try:
+        block_identifier = params[0]
+        transaction_index = to_integer_if_hex(params[1])
+        message = (
+            f"Transaction index: {transaction_index} "
+            f"on block id: {block_identifier!r} not found."
+        )
+    except IndexError:
+        message = "Unknown transaction index or block identifier"
+
+    raise TransactionNotFound(message)
 
 
 NULL_RESULT_FORMATTERS: Dict[RPCEndpoint, Callable[..., Any]] = {
@@ -627,6 +673,7 @@ NULL_RESULT_FORMATTERS: Dict[RPCEndpoint, Callable[..., Any]] = {
     RPC.eth_getTransactionByBlockHashAndIndex: raise_transaction_not_found_with_index,
     RPC.eth_getTransactionByBlockNumberAndIndex: raise_transaction_not_found_with_index,
     RPC.eth_getTransactionReceipt: raise_transaction_not_found,
+    RPC.eth_getRawTransactionByHash: raise_transaction_not_found,
 }
 
 
@@ -690,7 +737,15 @@ def get_error_formatters(
     method_name: Union[RPCEndpoint, Callable[..., RPCEndpoint]]
 ) -> Callable[..., Any]:
     #  Note error formatters work on the full response dict
-    error_formatter_maps = (NULL_RESULT_FORMATTERS, ERROR_FORMATTERS)
+    error_formatter_maps = (ERROR_FORMATTERS,)
     formatters = combine_formatters(error_formatter_maps, method_name)
 
     return compose(*formatters)
+
+
+def get_null_result_formatters(
+    method_name: Union[RPCEndpoint, Callable[..., RPCEndpoint]]
+) -> Callable[..., Any]:
+    formatters = combine_formatters((NULL_RESULT_FORMATTERS,), method_name)
+
+    return compose(*formatters)
